@@ -17,8 +17,8 @@ end
 function DiffEqBase.solve(jump_prob::JumpProblem, alg::SimpleTauLeaping;
         seed = nothing, dt = error("dt is required for SimpleTauLeaping."))
     validate_pure_leaping_inputs(jump_prob, alg) ||
-        error("SimpleTauLeaping can only be used with PureLeaping JumpProblems with only non-RegularJumps.")
-    
+        error("SimpleTauLeaping can only be used with PureLeaping JumpProblems with only RegularJumps.")
+
     @unpack prob, rng = jump_prob
     (seed !== nothing) && seed!(rng, seed)
 
