@@ -62,8 +62,7 @@ function configure_jump_problem(prob, vr_aggregator::VR_FRM, jumps, cvrjs;
         rng = DEFAULT_RNG)
     new_prob = extend_problem(prob, cvrjs; rng)
     variable_jump_callback = build_variable_callback(CallbackSet(), 0, cvrjs...; rng)
-    cont_agg = cvrjs
-    return new_prob, variable_jump_callback, cont_agg
+    return new_prob, variable_jump_callback
 end
 
 # extends prob.u0 to an ExtendedJumpArray with Njumps integrated intensity values,
@@ -338,7 +337,7 @@ function initialize_vr_direct_cache!(cache::VR_DirectEventCache, u, t, integrato
 end
 
 @inline function concretize_vr_direct_affects!(cache::VR_DirectEventCache,
-        ::I) where {I <: DiffEqBase.DEIntegrator}
+        ::I) where {I <: SciMLBase.DEIntegrator}
     if (cache.affect_funcs isa Vector) &&
        !(cache.affect_funcs isa Vector{FunctionWrappers.FunctionWrapper{Nothing, Tuple{I}}})
         AffectWrapper = FunctionWrappers.FunctionWrapper{Nothing, Tuple{I}}
@@ -349,7 +348,7 @@ end
 end
 
 @inline function concretize_vr_direct_affects!(cache::VR_DirectEventCache{T, RNG, F1, F2},
-        ::I) where {T, RNG, F1, F2 <: Tuple, I <: DiffEqBase.DEIntegrator}
+        ::I) where {T, RNG, F1, F2 <: Tuple, I <: SciMLBase.DEIntegrator}
     nothing
 end
 
@@ -381,16 +380,14 @@ function configure_jump_problem(prob, ::VR_Direct, jumps, cvrjs; rng = DEFAULT_R
     new_prob = prob
     cache = VR_DirectEventCache(jumps, VR_Direct(), prob, eltype(prob.tspan); rng)
     variable_jump_callback = build_variable_integcallback(cache, cvrjs)
-    cont_agg = cvrjs
-    return new_prob, variable_jump_callback, cont_agg
+    return new_prob, variable_jump_callback
 end
 
 function configure_jump_problem(prob, ::VR_DirectFW, jumps, cvrjs; rng = DEFAULT_RNG)
     new_prob = prob
     cache = VR_DirectEventCache(jumps, VR_DirectFW(), prob, eltype(prob.tspan); rng)
     variable_jump_callback = build_variable_integcallback(cache, cvrjs)
-    cont_agg = cvrjs
-    return new_prob, variable_jump_callback, cont_agg
+    return new_prob, variable_jump_callback
 end
 
 # recursively evaluate the cumulative sum of the rates for type stability 
@@ -458,7 +455,7 @@ function (cache::VR_DirectEventCache)(u, t, integrator)
 end
 
 @generated function execute_affect!(cache::VR_DirectEventCache{T, RNG, F1, F2},
-        integrator::I, idx) where {T, RNG, F1, F2 <: Tuple, I <: DiffEqBase.DEIntegrator}
+        integrator::I, idx) where {T, RNG, F1, F2 <: Tuple, I <: SciMLBase.DEIntegrator}
     quote
         @unpack affect_funcs = cache
         Base.Cartesian.@nif $(fieldcount(F2)) i -> (i == idx) i -> (@inbounds affect_funcs[i](integrator)) i -> (@inbounds affect_funcs[fieldcount(F2)](integrator))
@@ -466,7 +463,7 @@ end
 end
 
 @inline function execute_affect!(cache::VR_DirectEventCache,
-        integrator::I, idx) where {I <: DiffEqBase.DEIntegrator}
+        integrator::I, idx) where {I <: SciMLBase.DEIntegrator}
     @unpack affect_funcs = cache
     if affect_funcs isa Vector{FunctionWrappers.FunctionWrapper{Nothing, Tuple{I}}}
         @inbounds affect_funcs[idx](integrator)
